
-- Add initialUserId column - temp
ALTER TABLE users ADD COLUMN initialUserId int;

-- INSERT anonymous and user_deleted for each organization
INSERT INTO users (email, name, initialUserId, organizationId, organizationRole) 
SELECT users.email, users.name, users.userId, organizations.id, 'ROLE_ORGANIZATION_MEMBER' FROM `users`, `organizations` WHERE users.email = 'anonymous@anonymous.com' OR users.email = 'userdeleted@userdeleted.com';

-- Add other users to organizations

-- Create temp table
CREATE TABLE IF NOT EXISTS `temp` (
  initialUserId int NOT NULL,
  name varchar(128) NOT NULL,
  email varchar(256) NOT NULL,
  organizationId int NOT NULL,
  organizationRole varchar(256), 
  UNIQUE `user_organization_u`(`email`, `organizationId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=1;

-- Insert from user_subscriptions
INSERT INTO temp (email, name, initialUserId, organizationId, organizationRole) 
SELECT DISTINCT users.email, users.name, users.userId, user_subscriptions.organizationId, 'ROLE_ORGANIZATION_OWNER'
FROM user_subscriptions JOIN users on users.userId = user_subscriptions.userId; 

-- Insert from user role
INSERT INTO temp (email, name, initialUserId, organizationId, organizationRole)
SELECT DISTINCT users.email, users.name, users.userId,  sites.organizationId, 
IF (organizations.ownerId = users.userId, 'ROLE_ORGANIZATION_OWNER', 'ROLE_ORGANIZATION_MEMBER') as role 
FROM sites JOIN site_user_role on sites.siteId = site_user_role.siteId 
JOIN users on users.userId = site_user_role.userId 
JOIN organizations on organizations.id = sites.organizationId ON DUPLICATE KEY UPDATE temp.email = temp.email;

-- Insert from comments
INSERT INTO temp (email, name, initialUserId, organizationId, organizationRole) 
SELECT DISTINCT users.email, users.name, users.userId, sites.organizationId, 'ROLE_ORGANIZATION_MEMBER' FROM sites JOIN versions on sites.siteId = versions.siteId JOIN site_pages ON site_pages.versionId = versions.versionId JOIN comments on comments.site_page_id = site_pages.id JOIN users on users.userId = comments.userId JOIN organizations on organizations.id = sites.organizationId 
WHERE users.email != 'anonymous@anonymous.com' OR users.email != 'userdeleted@userdeleted.com' ON DUPLICATE KEY UPDATE temp.email = temp.email;

-- Preserve the original user id for users that have a subscription and they are now ORGANIZATION_OWNER.
UPDATE users JOIN temp ON users.userId = temp.initialUserId SET users.initialUserId = temp.initialUserId, users.organizationId = temp.organizationId, users.organizationRole = temp.organizationRole WHERE temp.organizationRole = 'ROLE_ORGANIZATION_OWNER';

-- Add to users 
INSERT INTO `users`(`email`, `name`, `initialUserId`, `organizationId`, `organizationRole`) SELECT temp.email, temp.name, temp.initialUserId, temp.organizationId, temp.organizationRole FROM temp ON DUPLICATE KEY UPDATE users.email = users.email;

-- Update the table to the new user IDs, except for the ones that we preserved the initial id (For the ones that have the organization role as ROLE_ORGANIZATION_OWNER).
-- User details
INSERT INTO `user_details`(`userId`, `company`, `creationDate`, `role`, `avatarName`, `deletionDate`, `publishTermsAccepted`) 
SELECT users.userId, user_details.company,  user_details.creationDate,  
IF (user_details.role = 'ROLE_APPLICATION_ADMIN', 
	IF(users.organizationRole = 'ROLE_ORGANIZATION_OWNER', 'ROLE_APPLICATION_ADMIN', 'ROLE_USER'), 
	user_details.role),  
user_details.avatarName,  user_details.deletionDate,  user_details.publishTermsAccepted from user_details 
JOIN users on user_details.userId = users.initialUserId WHERE users.organizationRole != 'ROLE_ORGANIZATION_OWNER';


-- Update the table to the new user IDs, except for the ones that we preserved the initial id (For the ones that have the organization role as ROLE_ORGANIZATION_OWNER).
-- Platform credentials
INSERT INTO `platform_credentials`(`userId`, `password`, `tryLegacyPassword`, `resetPasswordToken`, `tokenCreationDate`, `status`, `registrationDate`) 
SELECT users.userId, platform_credentials.password,  platform_credentials.tryLegacyPassword,  platform_credentials.resetPasswordToken,  platform_credentials.tokenCreationDate,  platform_credentials.status,  platform_credentials.registrationDate from platform_credentials JOIN users on platform_credentials.userId = users.initialUserId
WHERE users.organizationRole != 'ROLE_ORGANIZATION_OWNER';

-- Update the table to the new user IDs, except for the ones that we preserved the initial id (For the ones that have the organization role as ROLE_ORGANIZATION_OWNER).
-- OAuthCredentials
INSERT INTO `oauth_credentials`(`userId`, `oauthUserId`, `oauthProvider`) 
SELECT users.userId, oauth_credentials.oauthUserId,  oauth_credentials.oauthProvider  from oauth_credentials JOIN users on oauth_credentials.userId = users.initialUserId
WHERE users.organizationRole != 'ROLE_ORGANIZATION_OWNER';

--
-- START Update comments.userId from old values to new user IDs from organizations
--

CREATE TABLE `temp2` (
  initialUserId int NOT NULL,
  userId int NOT NULL,
  user_organization_id int NOT NULL,
  sites_organization_id int NOT NULL,
  site_page_id int NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=1;


INSERT INTO temp2 SELECT users.initialUserId, users.userId, users.organizationId as user_organization_id, sites.organizationId as sites_organization_id, site_pages.id FROM sites JOIN versions on sites.siteId = versions.siteId JOIN 
site_pages ON site_pages.versionId = versions.versionId JOIN comments on comments.site_page_id=site_pages.id JOIN users on users.initialUserId = comments.userId JOIN 
organizations on organizations.id = sites.organizationId 
WHERE users.initialUserId = comments.userId AND users.organizationId = sites.organizationId AND users.organizationRole != 'ROLE_ORGANIZATION_OWNER';

UPDATE `comments` JOIN temp2 ON temp2.initialUserId = comments.userId JOIN users ON users.userId = temp2.userId SET comments.`userId`= temp2.userId
WHERE temp2.sites_organization_id = users.organizationId AND temp2.initialUserId = comments.userId AND comments.site_page_id = temp2.site_page_id;

-- Remove temp2 table
DROP TABLE temp2;

--
-- END Update comments.userId from old values to new user IDs from organizations
--

-- Update the table to the new user IDs, except for the ones that we preserved the initial id (For the ones that have the organization role as ROLE_ORGANIZATION_OWNER).
-- Update lastEditedUserId
UPDATE `comments` JOIN site_pages on site_pages.id = comments.site_page_id JOIN versions on site_pages.versionId = versions.versionId JOIN 
sites ON sites.siteId = versions.siteId JOIN users on users.initialUserId = comments.lastEditUserId SET comments.lastEditUserId = users.userId WHERE 
comments.site_page_id=site_pages.id AND users.initialUserId = comments.lastEditUserId AND users.organizationId = sites.organizationId;

-- Update the table to the new user IDs, except for the ones that we preserved the initial id (For the ones that have the organization role as ROLE_ORGANIZATION_OWNER).
-- Update comments_actions_history
UPDATE `comments_actions_history` JOIN comments on comments.commentId = comments_actions_history.commentId JOIN site_pages on site_pages.id = comments.site_page_id JOIN 
versions on site_pages.versionId = versions.versionId JOIN sites ON sites.siteId = versions.siteId JOIN 
users on users.initialUserId = comments_actions_history.userId SET comments_actions_history.`userId`= users.userId 
WHERE comments.commentId = comments_actions_history.commentId AND users.organizationId = sites.organizationId;

-- Update the table to the new user IDs, except for the ones that we preserved the initial id (For the ones that have the organization role as ROLE_ORGANIZATION_OWNER).
-- Update email_notifications
INSERT INTO `email_notifications`(`userId`, `userNotifications`, `commentReply`, `pageComment`, `moderatorNotifications`, `commentAddedNeedsModeration`, `commentApproved`, 
`commentAdded`, `commentEdited`, `commentDeleted`, `commentRejected`, `commentRestored`, `commentResolved`, `commentReopened`, `adminNotifications`, 
`siteEdited`, `siteDeleted`, `versionAdded`, `versionEdited`, `versionDeleted`) SELECT users.userId, email_notifications.userNotifications,  
email_notifications.commentReply,  email_notifications.pageComment,  email_notifications.moderatorNotifications,  email_notifications.commentAddedNeedsModeration,  email_notifications.commentApproved, 
email_notifications.commentAdded, email_notifications.commentEdited, email_notifications.commentDeleted, email_notifications.commentRejected,
 email_notifications.commentRestored, email_notifications.commentResolved, email_notifications.commentReopened, email_notifications.adminNotifications, 
 email_notifications.siteEdited, email_notifications.siteDeleted, email_notifications.versionAdded, email_notifications.versionEdited, 
 email_notifications.versionDeleted from email_notifications JOIN users on email_notifications.userId = users.initialUserId WHERE users.organizationRole != 'ROLE_ORGANIZATION_OWNER';

-- Update the table to the new user IDs, except for the ones that we preserved the initial id (For the ones that have the organization role as ROLE_ORGANIZATION_OWNER).
-- Update pending_sites_role
UPDATE `pending_site_roles` JOIN sites on pending_site_roles.siteId = sites.siteId JOIN users on pending_site_roles.userId = users.initialUserId SET pending_site_roles.`userId`= users.userId WHERE sites.organizationId = users.organizationId AND users.organizationRole != 'ROLE_ORGANIZATION_OWNER';

-- Update the table to the new user IDs, except for the ones that we preserved the initial id (For the ones that have the organization role as ROLE_ORGANIZATION_OWNER).
-- Update site_user_role
UPDATE `site_user_role` JOIN sites on site_user_role.siteId = sites.siteId JOIN users on site_user_role.userId = users.initialUserId SET site_user_role.`userId`= users.userId WHERE sites.organizationId = users.organizationId AND users.organizationRole != 'ROLE_ORGANIZATION_OWNER';

-- Update the table to the new user IDs, except for the ones that we preserved the initial id (For the ones that have the organization role as ROLE_ORGANIZATION_OWNER).
-- Update user_site_email_notifications
UPDATE `user_site_email_notifications` JOIN sites on user_site_email_notifications.siteId = sites.siteId JOIN users on user_site_email_notifications.userId = users.initialUserId 
SET user_site_email_notifications.`userId`= users.userId WHERE sites.organizationId = users.organizationId AND users.organizationRole != 'ROLE_ORGANIZATION_OWNER';


-- subscription_history
-- Populate subscriptionId column
UPDATE `subscription_history` JOIN organizations on organizations.ownerId = subscription_history.userId JOIN user_subscriptions ON user_subscriptions.organizationId = organizations.id SET subscription_history.subscriptionId = user_subscriptions.id;

-- Update the table to the new user IDs, except for the ones that we preserved the initial id (For the ones that have the organization role as ROLE_ORGANIZATION_OWNER).
-- Update transfer_ownership ownerIDs
UPDATE `transfer_ownership` JOIN sites on transfer_ownership.siteId = sites.siteId JOIN users on transfer_ownership.c_ownerId = users.initialUserId 
SET transfer_ownership.c_ownerId= users.userId WHERE sites.organizationId = users.organizationId AND users.organizationRole != 'ROLE_ORGANIZATION_OWNER';

-- Update the table to the new user IDs, except for the ones that we preserved the initial id (For the ones that have the organization role as ROLE_ORGANIZATION_OWNER).
-- Update transfer_ownership new_ownersIDs
UPDATE `transfer_ownership` JOIN sites on transfer_ownership.siteId = sites.siteId JOIN users on transfer_ownership.n_ownerId = users.initialUserId 
SET transfer_ownership.n_ownerId = users.userId WHERE sites.organizationId = users.organizationId AND users.organizationRole != 'ROLE_ORGANIZATION_OWNER';

-- Update the table to the new user IDs, except for the ones that we preserved the initial id (For the ones that have the organization role as ROLE_ORGANIZATION_OWNER).
-- Update application_release_notifications 
UPDATE `application_release_notifications` JOIN users on application_release_notifications.userId = users.initialUserId 
SET application_release_notifications.`userId`= users.userId WHERE users.organizationRole = 'ROLE_ORGANIZATION_OWNER';

-- Update the table to the new user IDs, except for the ones that we preserved the initial id (For the ones that have the organization role as ROLE_ORGANIZATION_OWNER).
-- Update page_views_alarm
UPDATE `page_views_alarm` JOIN users on users.initialUserId = page_views_alarm.ownerId JOIN site_user_role on 
site_user_role.userId = users.userId JOIN sites on site_user_role.siteId = sites.siteId SET page_views_alarm.ownerId = users.userId 
WHERE users.organizationId = sites.organizationId AND site_user_role.role = 'ROLE_SITE_OWNER' AND users.organizationRole != 'ROLE_ORGANIZATION_OWNER';


-- Delete initialUserId column from users
ALTER TABLE users DROP COLUMN initialUserId;

-- Remove temp table
DROP TABLE temp;