--
-- Convert users table to UTF8
--
CREATE TABLE IF NOT EXISTS users_utf8 (
  userId int NOT NULL AUTO_INCREMENT,
  userName varchar(128) NOT NULL,
  email varchar(256) NOT NULL,
  name varchar(256) NOT NULL,
  company varchar(256) NOT NULL,
  password varchar(256) NOT NULL,
  date datetime NOT NULL,
  level enum('user','admin','moderator') NOT NULL DEFAULT 'user',
  status enum('created','validated','suspended') NOT NULL DEFAULT 'created',
  notifyAll enum('yes','no') NOT NULL DEFAULT 'no',
  notifyReply enum('yes','no') NOT NULL DEFAULT 'no',
  notifyPage enum('yes','no') NOT NULL DEFAULT 'no',
  PRIMARY KEY (userId),
  UNIQUE KEY userName (userName),
  UNIQUE KEY email (email)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=1 ;

INSERT INTO users_utf8 (userId, userName, email, name, company, password, date, level, status, notifyAll, notifyReply, notifyPage) 
SELECT 
CONVERT(CAST(userId as BINARY) USING utf8mb4),
CONVERT(CAST(userName as BINARY) USING utf8mb4),
CONVERT(CAST(email as BINARY) USING utf8mb4),
CONVERT(CAST(name as BINARY) USING utf8mb4),
CONVERT(CAST(company as BINARY) USING utf8mb4),
CONVERT(CAST(password as BINARY) USING utf8mb4),
CONVERT(CAST(date as BINARY) USING utf8mb4),
CONVERT(CAST(level as BINARY) USING utf8mb4),
CONVERT(CAST(status as BINARY) USING utf8mb4),
CONVERT(CAST(notifyAll as BINARY) USING utf8mb4),
CONVERT(CAST(notifyReply as BINARY) USING utf8mb4),
CONVERT(CAST(notifyPage as BINARY) USING utf8mb4)
FROM users;

DROP TABLE users;
ALTER TABLE users_utf8 RENAME TO users;

--
-- Convert comments table to UTF8
--
CREATE TABLE IF NOT EXISTS comments_utf8 (
  commentId int NOT NULL AUTO_INCREMENT,
  text longtext NOT NULL,
  userId int NOT NULL,
  referedComment int NOT NULL,
  date timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  state enum('new','approved','rejected','suspended') NOT NULL,
  page varchar(512) NOT NULL,
  product varchar(256) NOT NULL,
  version varchar(128) NOT NULL,
  visible enum('true','false') NOT NULL,
  PRIMARY KEY (commentId)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=1 ;

INSERT INTO comments_utf8 (commentId, text, userId, referedComment, date, state, page, product, version, visible) 
SELECT 
CONVERT(CAST(commentId as BINARY) USING utf8mb4),
CONVERT(CAST(text as BINARY) USING utf8mb4),
CONVERT(CAST(userId as BINARY) USING utf8mb4),
CONVERT(CAST(referedComment as BINARY) USING utf8mb4),
CONVERT(CAST(date as BINARY) USING utf8mb4),
CONVERT(CAST(state as BINARY) USING utf8mb4),
CONVERT(CAST(page as BINARY) USING utf8mb4),
CONVERT(CAST(product as BINARY) USING utf8mb4),
CONVERT(CAST(version as BINARY) USING utf8mb4),
CONVERT(CAST(visible as BINARY) USING utf8mb4)
FROM comments;

DROP TABLE comments;
ALTER TABLE comments_utf8 RENAME TO comments;

--
-- Convert webhep table to UTF8
--
CREATE TABLE IF NOT EXISTS webhelp_utf8 (
  parameter varchar(256) NOT NULL,
  value varchar(512) NOT NULL,
  product varchar(256) NOT NULL,
  version varchar(256) NOT NULL,
  UNIQUE KEY parameter (parameter,product,version)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


INSERT INTO webhelp_utf8 (parameter, value, product, version) 
SELECT 
CONVERT(CAST(parameter as BINARY) USING utf8mb4),
CONVERT(CAST(value as BINARY) USING utf8mb4),
CONVERT(CAST(product as BINARY) USING utf8mb4),
CONVERT(CAST(version as BINARY) USING utf8mb4)
FROM webhelp;

DROP TABLE webhelp;
ALTER TABLE webhelp_utf8 RENAME TO webhelp;