-- Procedures
DROP PROCEDURE IF EXISTS POPULATE_PAGE_SITES_FROM_COMMENTS();
CREATE PROCEDURE POPULATE_PAGE_SITES_FROM_COMMENTS()
LANGUAGE plpgsql
AS $$
DECLARE n INT DEFAULT 0;
DECLARE i INT DEFAULT 0;  
DECLARE p_ VARCHAR DEFAULT NULL;
DECLARE p_Title VARCHAR DEFAULT NULL;
DECLARE p_VersionId INT DEFAULT 0;
DECLARE p_id INT DEFAULT 0;  
BEGIN
	CREATE TEMPORARY TABLE IF NOT EXISTS pages AS SELECT page, pageTitle, versionId from comments GROUP BY page, pageTitle, versionId;
	
	SELECT COUNT(*) INTO n FROM pages;
	i = 0;
	WHILE i<n LOOP
    	SELECT pages.page INTO p_ FROM pages LIMIT 1 OFFSET i;
		SELECT pages.pageTitle INTO p_Title FROM pages LIMIT 1 OFFSET i;
		SELECT pages.versionId INTO p_VersionId FROM pages LIMIT 1 OFFSET i;
		SELECT site_pages.id INTO p_id FROM site_pages WHERE relPath=p_ AND versionId=p_VersionId;

		IF p_ IS NOT NULL AND p_VersionId IS NOT NULL THEN
          IF p_id IS NULL THEN
        	INSERT INTO site_pages(relPath, title, versionId) VALUES (p_, p_Title, p_VersionId);
        	SELECT site_pages.id INTO p_id FROM site_pages WHERE relPath=p_ AND versionId=p_VersionId;
          END IF;
        
          UPDATE comments SET site_page_id=p_id WHERE page=p_ AND versionId=p_VersionId;
 		END IF;
 		
		i = i + 1;
	END LOOP;
	
    DROP TABLE IF EXISTS pages;
END
$$;

--

DROP PROCEDURE IF EXISTS POPULATE_PAGE_SITES_FROM_VIEW_RECORDS();
CREATE PROCEDURE POPULATE_PAGE_SITES_FROM_VIEW_RECORDS()
LANGUAGE plpgsql
AS $$
DECLARE n INT DEFAULT 0;
DECLARE i INT DEFAULT 0;  
DECLARE _page VARCHAR DEFAULT NULL;
DECLARE p_Title VARCHAR DEFAULT NULL;
DECLARE p_VersionId INT DEFAULT 0;
DECLARE p_id INT DEFAULT 0;  
BEGIN
	CREATE TEMPORARY TABLE IF NOT EXISTS pages AS SELECT pagePath, pageTitle, versionId from page_views_record GROUP BY pagePath, pageTitle, versionId;
	
	SELECT COUNT(*) INTO n FROM pages;
	i = 0;
	WHILE i<n LOOP
    	SELECT pages.pagePath INTO _page FROM pages LIMIT 1 OFFSET i;
		SELECT pages.pageTitle INTO p_Title FROM pages LIMIT 1 OFFSET i;
		SELECT pages.versionId INTO p_VersionId FROM pages LIMIT 1 OFFSET i;
		SELECT site_pages.id INTO p_id FROM site_pages WHERE relPath=_page AND versionId=p_VersionId;

		IF _page IS NOT NULL AND p_VersionId IS NOT NULL THEN
          IF p_id IS NULL THEN
        	INSERT INTO site_pages(relPath, title, versionId) VALUES (_page, p_Title, p_VersionId);
        	SELECT site_pages.id INTO p_id FROM site_pages WHERE relPath=_page AND versionId=p_VersionId;
          END IF;
        
          UPDATE page_views_record SET site_page_id=p_id WHERE pagePath=_page AND versionId=p_VersionId;
 		END IF;
 		
		i = i + 1;
	END LOOP;
	
    DROP TABLE IF EXISTS pages;
END
$$;


-- Create site_pages table

CREATE TABLE IF NOT EXISTS site_pages (
  id SERIAL NOT NULL,
  relPath varchar(511),
  wh_sourceRelPath varchar(511) DEFAULT NULL,
  title varchar(511),
  versionId integer NOT NULL,
  PRIMARY KEY (id),
  UNIQUE (relPath, versionId)
);

-- Add site_page_id column to comments (later will be foreign key)
  ALTER TABLE comments ADD COLUMN site_page_id integer;
  ALTER TABLE comments ALTER COLUMN site_page_id SET NOT NULL;

-- Add site_page_id column to page_views_record (later will be foreign key)
   ALTER TABLE page_views_record ADD COLUMN site_page_id integer;
   ALTER TABLE page_views_record ALTER COLUMN site_page_id SET NOT NULL;

-- Update comments
  CALL POPULATE_PAGE_SITES_FROM_COMMENTS();

-- Update page_views_record
  CALL POPULATE_PAGE_SITES_FROM_VIEW_RECORDS();
  
  -- Remove versionId foreign key constraint
  ALTER TABLE comments DROP CONSTRAINT comments_versionid_fkey;
  ALTER TABLE page_views_record DROP CONSTRAINT page_views_record_versionid_fkey;

-- Add foreign keys for comments and page_view_records 
    ALTER TABLE comments ADD CONSTRAINT c_site_page_fkey FOREIGN KEY (site_page_id) REFERENCES site_pages (id);
    
    ALTER TABLE page_views_record ADD CONSTRAINT r_site_page_fkey FOREIGN KEY (site_page_id) REFERENCES site_pages (id);
    
    ALTER TABLE site_pages ADD CONSTRAINT versions_fkey FOREIGN KEY (versionId) REFERENCES versions (versionId);

-- Drop columns page and pageTitle from comments
	ALTER TABLE comments 
		DROP COLUMN page, 
		DROP COLUMN pageTitle,
		DROP COLUMN versionId;
		
-- Drop columns pagePath and pageTitle from page_views_record
	ALTER TABLE page_views_record 
		DROP COLUMN pagePath, 
		DROP COLUMN pageTitle,
		DROP COLUMN versionId;

-- Delete procedures
DROP PROCEDURE IF EXISTS POPULATE_PAGE_SITES_FROM_COMMENTS();
DROP PROCEDURE IF EXISTS POPULATE_PAGE_SITES_FROM_VIEW_RECORDS();